@@ -189,7 +189,7 @@ class VersionSynchronizer:
         except Exception as e:
             raise RuntimeError(f"Failed to read version from formula: {e}") from e
 
-    def validate_version_consistency(self) -> VersionConsistencyReport:
+    def validate_version_consistency(self, release_mode: bool = False) -> VersionConsistencyReport:
         """Validate version consistency across all components.
 
         Returns:
@@ -221,16 +221,39 @@ class VersionSynchronizer:
             recommended_actions = []
 
             # Extract discrepancies from validation report
+            all_discrepancies = []
+            core_discrepancies = []
+
             for issue in validation_report.issues:
                 if issue.expected_version and issue.actual_version:
                     discrepancy = (
                         f"{issue.component}: {issue.actual_version} != {issue.expected_version}"
                     )
-                    discrepancies.append(discrepancy)
-                    if issue.suggestion:
-                        recommended_actions.append(issue.suggestion)
+                    all_discrepancies.append(discrepancy)
 
-            is_consistent = validation_report.is_consistent
+                    # In release mode, only track core component discrepancies
+                    if issue.component not in ["homebrew_formula", "binary"]:
+                        core_discrepancies.append(discrepancy)
+                        if issue.suggestion:
+                            recommended_actions.append(issue.suggestion)
+                    elif release_mode:
+                        logger.info(
+                            f"Ignoring {issue.component} discrepancy in release mode: {discrepancy}"
+                        )
+
+            # Determine consistency based on mode
+            if release_mode:
+                is_consistent = len(core_discrepancies) == 0
+                discrepancies = core_discrepancies
+                if is_consistent:
+                    logger.info("✅ Core components are consistent (release mode)")
+                else:
+                    logger.warning(
+                        f"❌ Found {len(core_discrepancies)} core component discrepancies"
+                    )
+            else:
+                is_consistent = len(all_discrepancies) == 0
+                discrepancies = all_discrepancies
 
             if is_consistent:
                 logger.info("✅ All versions are consistent")
@@ -883,6 +906,12 @@ This script ensures version consistency by:
         help="Path to homebrew repository (defaults to ../homebrew-riveter)",
     )
 
+    parser.add_argument(
+        "--release-mode",
+        action="store_true",
+        help="Release mode: only validate core components, skip external ones",
+    )
+
     args = parser.parse_args()
 
     # Validate arguments
@@ -909,7 +938,7 @@ This script ensures version consistency by:
         )
 
         if args.validate:
-            report = synchronizer.validate_version_consistency()
+            report = synchronizer.validate_version_consistency(release_mode=args.release_mode)
 
             print("\n📊 Version Consistency Report")
             print("=" * 50)
